==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-taskbar/taskbar_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="641"/>
        <source>Activate task %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="478"/>
        <source>Application</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="512"/>
        <source>To &amp;Desktop</source>
        <translation>傳送到桌面(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>&amp;All Desktops</source>
        <translation>傳送到全部桌面(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="522"/>
        <source>Desktop &amp;%1</source>
        <translation>桌面 &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="529"/>
        <source>&amp;To Current Desktop</source>
        <translation>傳送到當前桌面(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="538"/>
        <source>Ma&amp;ximize</source>
        <translation>最大化(&amp;x)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
        <source>Maximize vertically</source>
        <translation>垂直最大化</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>Maximize horizontally</source>
        <translation>水平最大化</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="556"/>
        <source>&amp;Restore</source>
        <translation>恢復(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="560"/>
        <source>Mi&amp;nimize</source>
        <translation>最小化(&amp;n)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="566"/>
        <source>Roll down</source>
        <translation>放下視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="572"/>
        <source>Roll up</source>
        <translation>捲起視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="580"/>
        <source>&amp;Layer</source>
        <translation>層(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="582"/>
        <source>Always on &amp;top</source>
        <translation>總是在最上層(&amp;t)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="588"/>
        <source>&amp;Normal</source>
        <translation>正常(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="594"/>
        <source>Always on &amp;bottom</source>
        <translation>總是在最底層(&amp;b)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="602"/>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">LXQt工作管理員設定</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">視窗清單內容</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">顯示當前桌面視窗</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">顯示所有桌面視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">視窗清單外觀</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>按鈕樣式</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">最大按鈕寬度</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>按滑鼠中鍵關閉</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>圖示與文字</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>僅圖示</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>僅文字</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-taskbar/taskbar_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="644"/>
        <source>Activate task %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>Application</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
        <source>To &amp;Desktop</source>
        <translation>傳送到桌面(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>&amp;All Desktops</source>
        <translation>傳送到全部桌面(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
        <source>Desktop &amp;%1</source>
        <translation>桌面 &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>&amp;To Current Desktop</source>
        <translation>傳送到當前桌面(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
        <source>Resi&amp;ze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
        <source>Ma&amp;ximize</source>
        <translation>最大化(&amp;x)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
        <source>Maximize vertically</source>
        <translation>垂直最大化</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
        <source>Maximize horizontally</source>
        <translation>水平最大化</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Restore</source>
        <translation>恢復(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
        <source>Mi&amp;nimize</source>
        <translation>最小化(&amp;n)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
        <source>Roll down</source>
        <translation>放下視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
        <source>Roll up</source>
        <translation>捲起視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Layer</source>
        <translation>層(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
        <source>Always on &amp;top</source>
        <translation>總是在最上層(&amp;t)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
        <source>&amp;Normal</source>
        <translation>正常(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
        <source>Always on &amp;bottom</source>
        <translation>總是在最底層(&amp;b)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">LXQt工作管理員設定</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">視窗清單內容</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>工作管理員設定</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>僅顯示桌面上的視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>僅顯示最小化視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>在當前桌面展開最小化的視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>最大按鈕寬度</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation>像素</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>最大按鈕高度</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">顯示當前桌面視窗</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">顯示所有桌面視窗</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">視窗清單外觀</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>按鈕樣式</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">最大按鈕寬度</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>按滑鼠中鍵關閉</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>圖示與文字</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>僅圖示</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>僅文字</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
